@@ -129,6 +129,11 @@ AlarmIdentifierTypeDef = TypedDict(
             "sa-east-1",
             "cn-northwest-1",
             "cn-north-1",
+            "af-south-1",
+            "us-gov-west-1",
+            "us-gov-east-1",
+            "us-iso-east-1",
+            "us-isob-east-1",
         ],
         "Name": str,
     },
@@ -197,6 +202,7 @@ _OptionalResourceRecordSetTypeDef = TypedDict(
             "ap-east-1",
             "me-south-1",
             "ap-south-1",
+            "af-south-1",
         ],
         "GeoLocation": GeoLocationTypeDef,
         "Failover": Literal["PRIMARY", "SECONDARY"],
@@ -407,6 +413,10 @@ VPCTypeDef = TypedDict(
             "eu-central-1",
             "ap-east-1",
             "me-south-1",
+            "us-gov-west-1",
+            "us-gov-east-1",
+            "us-iso-east-1",
+            "us-isob-east-1",
             "ap-southeast-1",
             "ap-southeast-2",
             "ap-south-1",
@@ -417,6 +427,7 @@ VPCTypeDef = TypedDict(
             "sa-east-1",
             "ca-central-1",
             "cn-north-1",
+            "af-south-1",
         ],
         "VPCId": str,
     },
